@@ -50,8 +50,8 @@
         stop("Use only with 'between' objects")
     if ((bet$nf == 1) || (xax == yax)) {
         appel <- as.list(bet$call)
-        dudi <- eval(appel$dudi, sys.frame(0))
-        fac <- eval(appel$fac, sys.frame(0))
+        dudi <- eval.parent(appel$dudi)
+        fac <- eval.parent(appel$fac)
         lig <- nrow(dudi$tab)
         if (length(fac) != lig) 
             stop("Non convenient dimension")
@@ -62,7 +62,7 @@
         stop("Non convenient xax")
     if (yax > bet$nf) 
         stop("Non convenient yax")
-    fac <- eval(as.list(bet$call)$fac, sys.frame(0))
+    fac <- eval.parent(as.list(bet$call)$fac)
     def.par <- par(no.readonly = TRUE)
     on.exit(par(def.par))
     layout(matrix(c(1, 2, 3, 4, 4, 5, 4, 4, 6), 3, 3), 
@@ -103,8 +103,8 @@
     sumry[1, ] <- c("$eig", length(x$eig), mode(x$eig), "eigen values")
     sumry[2, ] <- c("$lw", length(x$lw), mode(x$lw), "group weigths")
     sumry[3, ] <- c("$cw", length(x$cw), mode(x$cw), "col weigths")
-    class(sumry) <- "table"
-    print(sumry)
+    
+    print(sumry, quote = FALSE)
     cat("\n")
     sumry <- array("", c(7, 4), list(1:7, c("data.frame", "nrow", 
         "ncol", "content")))
@@ -115,7 +115,7 @@
     sumry[5, ] <- c("$c1", nrow(x$c1), ncol(x$c1), "column normed scores")
     sumry[6, ] <- c("$ls", nrow(x$ls), ncol(x$ls), "row coordinates")
     sumry[7, ] <- c("$as", nrow(x$as), ncol(x$as), "inertia axis onto between axis")
-    class(sumry) <- "table"
-    print(sumry)
+    
+    print(sumry, quote = FALSE)
     cat("\n")
 }
