@@ -20,7 +20,7 @@
         coofull <- coo1
         for (i in which.tab) coofull <- rbind.data.frame(coofull, 
             cootot[object$TL[, 1] == i, ])
-        s.label(coo1, clab = clab, sub = "Reference", possub = "bottomright", 
+        s.label(coo1, clabel = clab, sub = "Reference", possub = "bottomright", 
             csub = csub)
         for (ianal in which.tab) {
             scatterutil.base(coofull, 1, 2, xlim = NULL, ylim = NULL, 
@@ -29,8 +29,8 @@
                 csub = csub, possub = possub, pixmap = NULL, 
                 contour = NULL, area = NULL, add.plot = FALSE)
             coo2 <- cootot[object$TL[, 1] == ianal, 1:2]
-            s.match(coo1, coo2, clab = 0, add.p = TRUE)
-            s.label(coo1, clab = 0, cpoi = cpoint, add.p = TRUE)
+            s.match(coo1, coo2, clabel = 0, add.plot = TRUE)
+            s.label(coo1, clabel = 0, cpoint = cpoint, add.plot = TRUE)
         }
         return(invisible())
     }
@@ -43,7 +43,7 @@
         for (ianal in which.tab) {
             coo2 <- object$Tax[object$T4[, 1] == ianal, c(xax, yax)]
             row.names(coo2) <- as.character(1:4)
-            s.corcircle(coo2, clab = clab, sub = row.names(object$cov2)[ianal], 
+            s.corcircle(coo2, clabel = clab, sub = row.names(object$cov2)[ianal], 
                 csub = csub, possub = possub)
         }
         return(invisible())
@@ -53,7 +53,7 @@
             par(ask = TRUE)
         for (ianal in which.tab) {
             coo2 <- object$Tco[object$TC[, 1] == ianal, c(xax, yax)]
-            s.arrow(coo2, clab = clab, sub = row.names(object$cov2)[ianal], 
+            s.arrow(coo2, clabel = clab, sub = row.names(object$cov2)[ianal], 
                 csub = csub, possub = possub)
         }
         return(invisible())
