@@ -17,14 +17,11 @@ testertrace <- function(npermut, pc1, pc2, tab1, tab2, l1, c1, c2)
     .C("testertrace",
         as.integer(npermut),
         as.double(pc1),
-        as.integer(length(pc1)),
         as.double(pc2),
-        as.integer(length(pc2)),
         as.double(t(tab1)),
         as.integer(l1),
         as.integer(c1),
         as.double(t(tab2)),
-        as.integer(l1),
         as.integer(c2),
         inersim = double(npermut+1),
         PACKAGE="ade4")$inersim
@@ -33,16 +30,12 @@ testertracenu <- function(npermut, pc1, pc2, pl, tab1, tab2, l1, c1, c2, Xinit,
     .C("testertracenu",
         as.integer(npermut),
         as.double(pc1),
-        as.integer(length(pc1)),
         as.double(pc2),
-        as.integer(length(pc2)),
-        as.double(pl),
-        as.integer(length(pl)),
+        as.double(pl),       
         as.double(t(tab1)),
         as.integer(l1),
         as.integer(c1),
         as.double(t(tab2)),
-        as.integer(l1),
         as.integer(c2),
         as.double(t(Xinit)),
         as.double(t(Yinit)),
@@ -55,16 +48,12 @@ testertracenubis <- function(npermut, pc1, pc2, pl, tab1, tab2, l1, c1, c2, Xini
     .C("testertracenubis",
         as.integer(npermut),
         as.double(pc1),
-        as.integer(length(pc1)),
         as.double(pc2),
-        as.integer(length(pc2)),
         as.double(pl),
-        as.integer(length(pl)),
         as.double(t(tab1)),
         as.integer(l1),
         as.integer(c1),
         as.double(t(tab2)),
-        as.integer(l1),
         as.integer(c2),
         as.double(t(Xinit)),
         as.double(t(Yinit)),
